summaryrefslogtreecommitdiff
path: root/web/share/js/kvm/msd.js
diff options
context:
space:
mode:
authorMaxim Devaev <[email protected]>2021-09-08 06:47:54 +0300
committerMaxim Devaev <[email protected]>2021-09-08 06:47:54 +0300
commit8f11fa3b91921a6037b56ead0853928b1404de0f (patch)
tree45c002095795db7b8a23e5043d16b46a89e9485a /web/share/js/kvm/msd.js
parentca812117e48cbc6e2c71947b912748cfd3ff9691 (diff)
small rebranding
Diffstat (limited to 'web/share/js/kvm/msd.js')
-rw-r--r--web/share/js/kvm/msd.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/web/share/js/kvm/msd.js b/web/share/js/kvm/msd.js
index 93551c31..6999697f 100644
--- a/web/share/js/kvm/msd.js
+++ b/web/share/js/kvm/msd.js
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
# KVMD - The main Pi-KVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #
# #
@@ -71,7 +71,7 @@ export function Msd() {
var __clickRemoveButton = function() {
let name = $("msd-image-selector").value;
- wm.confirm(`Are you sure you want to remove the image<br><b>${name}</b> from Pi-KVM?`).then(function(ok) {
+ wm.confirm(`Are you sure you want to remove the image<br><b>${name}</b> from PiKVM?`).then(function(ok) {
if (ok) {
let http = tools.makeRequest("POST", `/api/msd/remove?image=${name}`, function() {
if (http.readyState === 4) {
@@ -1,6 +1,6 @@
/*****************************************************************************
# #
-# KVMD - The main Pi-KVM daemon. #
+# KVMD - The main PiKVM daemon. #
# #
# Copyright (C) 2018-2021 Maxim Devaev <[email protected]> #